summaryrefslogtreecommitdiff
path: root/home.asm
diff options
context:
space:
mode:
Diffstat (limited to 'home.asm')
-rw-r--r--home.asm14
1 files changed, 7 insertions, 7 deletions
diff --git a/home.asm b/home.asm
index eef727909..fca23f9f7 100644
--- a/home.asm
+++ b/home.asm
@@ -472,17 +472,17 @@ CallPointerAt:: ; 31be
; 31cd
-ExitMenuCallScript:: ; 31cd
-; Push pointer hl in the current bank to wd0e8.
+QueueScript:: ; 31cd
+; Push pointer hl in the current bank to wQueuedScriptBank.
ld a, [hROMBank]
-Function31cf:: ; 31cf
-; Push pointer a:hl to wd0e8.
- ld [wd0e8], a
+FarQueueScript:: ; 31cf
+; Push pointer a:hl to wQueuedScriptBank.
+ ld [wQueuedScriptBank], a
ld a, l
- ld [wd0e9], a
+ ld [wQueuedScriptAddr], a
ld a, h
- ld [wd0e9 + 1], a
+ ld [wQueuedScriptAddr + 1], a
ret
; 31db